#include "efm32jg1b100f128gm32.h"
#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include "msIoGeneric.h"
#include "msClassic.h"
#include "msPro.h"
#include "msioHL.h"
#include "msioLL.h"
#include "printf.h"
#include "timer.h"
#include "util.h"



static void hwInit(void)
{
	//set clock for 13MHz
	CMU->HFRCOCTRL = DEVINFO->HFRCOCAL6;	//was HFRCOCAL12 (38mhz)

	timerInit();
	
	asm volatile("cpsie i");
	
	CMU->HFBUSCLKEN0 |= CMU_HFBUSCLKEN0_GPIO;
	
	
	//pins and configs
	GPIO->P[1].CTRL &=~ 0x70;
	GPIO->P[1].CTRL |= 0x70;
}




void main(void)
{
	uint8_t regs[8], intVal;
	
	hwInit();
	msioLlInit();
	
	pr("test\n");
	
	if (!msioHlSetRegAddrs(0, sizeof(regs), 0x10, 0x10))
		pr("Failed to set ID regs addrs\n");
	else if (!msioHlRegsRead(regs, sizeof(regs)))
		pr("Failed to read ID regs\n");
	else if (msproIsMspro(regs)) {
		
		pr("MS PRO IDENTIFIED\n");
		msproDemo();
	}
	else if (msClassicIsMsClassic(regs)) {
		
		pr("MS CLASSIC IDENTIFIED\n");
		msClassicDemo();
	}
	else if (msIoGenericIsMSIO(regs)) {
		
		pr("MSIO IDENTIFIED\n");
		msIoGenericDemo();
	}
	else {
		
		pr("UNKNOWN PRODUCT ID:\n");
		showBuf(regs, sizeof(regs));
	}
	
fail:
	while(1);
}

